Basic Guides
************

This section goes through all elements of Balder and describes them in detail. Before going through this section, we
always recommend to start with the complete :ref:`Getting Started <Getting Started>` and :ref:`Tutorial Guide` section
before going deeper.

The different subsections of this chapter are created independently from each other. So feel free to jump to the
subsection you want to learn more about.

If you want to get a deeper understanding how Balder is implemented internally or if you have some specific questions
about some of these topics, please take a look at the `Reference Guides <../deeper>`_.

.. toctree::
    :maxdepth: 2
    :caption: Basic Guides


    execution_mechanism.rst
    scenarios.rst
    setups.rst
    devices.rst
    features.rst
    connections.rst
    vdevices.rst
    fixtures.rst
    parametrization.rst
    configuration.rst
    balderhub.rst
